## Movie theater

### Description

Conjoint data from one respondent. Rankings reflect the evaluation of 18 alternative movie theaters. The 18 profiles are an orthogonal fractional factorial design.

### Format

A data frame with 18 observations on 6 variables.

- Ranking = Respondent ranking of the 18 profiles. 1 is least preferred, 18 is most preferred.
- price = Cost of a ticket
- sight = Line of sight in the theater. A movie theater that is labeled 'Staggered' has seating that is higher in the back of the theater than in the front. In contrast, in a 'Not Staggered' theater all seats are on the same level.
- comfort = Factor with three levels. Large seat with a cupholder, Average seat with a cupholder, and Average seat without a cupholder.
- audio_visual = Factor with three levels. Large screen with digital sound, Large screen with plain sound, and Small screen with plain sound.
- food = Available food options in the theater